@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.000_020';
+our $VERSION = '0.000_021';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -329,6 +329,28 @@ sub alien_build {
   my $commands = $self->alien_build_commands;
 
   foreach my $command (@$commands) {
+
+    # hack Mac LDFLAGS
+    if (($^O eq 'darwin') and ($command =~ /\bmake(?:\.pl)?$/)) {
+      # probe for LDFLAGS variable in make database
+      my $vars = `make -p -n` || '';
+      my $ldflags = '';
+      if ($vars =~ /^\s*LDFLAGS\h*=\h*(.*)$/m) {
+        $ldflags = $1;
+        print STDERR "Found LDFLAGS = $ldflags\n";
+        $ldflags .= ' ';
+        
+      }
+
+      # add needed flag and set LDFLAGS env var
+      $ldflags .= '-headerpad_max_install_names';
+      $ENV{LDFLAGS} = $ldflags;
+      print STDERR "Using LDFLAGS = $ldflags\n";
+
+      # tell make to use the env vars over internal variables
+      $command .= ' -e';
+    }
+
     my %result = $self->do_system( $command );
     unless ($result{success}) {
       carp "External command ($command) failed! Error: $?\n";
@@ -512,13 +534,16 @@ sub alien_find_lib_paths {
 # overload c_i_m to handle Mac's dylib relocalization
 sub copy_if_modified {
   my $self = shift;
-  my $to_path = $self->SUPER::copy_if_modified(@_);
+  my $to_path = $self->SUPER::copy_if_modified(@_) or return;
 
-  return $to_path unless $self->os_type() eq 'MacOS';
+  return $to_path unless $^O eq 'darwin';
   return $to_path unless $to_path =~ /\.dylib$/;
 
   # handle dylib path relocalization
-  print "Todo: Handling Mac dylib paths\n";
+  # circumvent Alien::Base::MB's interpolation engine
+  $to_path = File::Spec->rel2abs($to_path);
+  $self->SUPER::do_system("install_name_tool -id $to_path $to_path")
+    or carp("dylib localization failed");
 
   return $to_path;
 }
