@@ -9,6 +9,7 @@ use Data::Dumper;
 use File::chdir;
 use File::Spec;
 use File::Copy qw/copy/;
+use File::Basename;
 
 use ExtUtils::LibBuilder;
 
@@ -53,9 +54,15 @@ sub build {
     # Link
     my $so = "libdontpanic$libbuilder->{libext}";
     my $soname = $^O eq 'darwin' ? '-install_name' : '-soname';
+    my $ldflags = "-Wl,$soname,$so";
+
+    if ( $ENV{LDFLAGS} ) {
+      $ldflags .= $ENV{LDFLAGS};
+    }
+
     $libbuilder->link(
       objects  => [ $o ],
-      extra_linker_flags => "-Wl,$soname,$so",
+      extra_linker_flags => $ldflags,
       lib_file => $so,
     );
 	
@@ -92,6 +99,11 @@ sub install {
     local $CWD = $folder;
     foreach my $file (@{$files{$folder}}) {
       copy $file, $CWD or die "Could not copy file $file";
+      if ($file =~ /\.dylib$/) {
+        my $filename = fileparse($file);
+        $filename = File::Spec->rel2abs($filename);
+        system("install_name_tool -id $filename $filename") == 0 or warn "Could not install dylib";
+      }
     }
     _write_pc() if $folder eq 'lib';
   }
